"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.trim = void 0;
const runtime_1 = require("../../../error/runtime");
const phpTrim = require('locutus/php/strings/trim');
const phpLeftTrim = require('locutus/php/strings/ltrim');
const phpRightTrim = require('locutus/php/strings/rtrim');
/**
 * Returns a trimmed string.
 *
 * @returns {Promise<string>}
 *
 * @throws TwingErrorRuntime When an invalid trimming side is used (not a string or not 'left', 'right', or 'both')
 */
const trim = (_executionContext, string, characterMask, side) => {
    const _do = () => {
        if (characterMask === null) {
            characterMask = " \t\n\r\0\x0B";
        }
        switch (side) {
            case 'both':
                return phpTrim(string, characterMask);
            case 'left':
                return phpLeftTrim(string, characterMask);
            case 'right':
                return phpRightTrim(string, characterMask);
            default:
                throw (0, runtime_1.createRuntimeError)('Trimming side must be "left", "right" or "both".');
        }
    };
    try {
        return Promise.resolve(_do());
    }
    catch (error) {
        return Promise.reject(error);
    }
};
exports.trim = trim;
