"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTraceableMethod = void 0;
const error_1 = require("../error");
const runtime_1 = require("../error/runtime");
function getTraceableMethod(method, line, column, templateName) {
    return ((...args) => {
        return method(...args)
            .catch((error) => {
            if ((0, error_1.isATwingError)(error)) {
                if (error.location === undefined) {
                    error.location = { line, column };
                    error.source = templateName;
                }
            }
            else {
                throw (0, runtime_1.createRuntimeError)(`An exception has been thrown during the rendering of a template ("${error.message}").`, {
                    line,
                    column
                }, templateName, error);
            }
            throw error;
        });
    });
}
exports.getTraceableMethod = getTraceableMethod;
