"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDeprecatedTagHandler = void 0;
const deprecated_1 = require("../node/deprecated");
/**
 * Deprecates a section of a template.
 *
 * <pre>
 * {% deprecated 'The "base.twig" template is deprecated, use "layout.twig" instead.' %}
 *
 * {% extends 'layout.html.twig' %}
 * </pre>
 *
 * @author Eric MORAND <eric.morand@gmail.com>
 */
const createDeprecatedTagHandler = () => {
    const tag = 'deprecated';
    return {
        tag,
        initialize: (parser) => {
            return (token, stream) => {
                const expression = parser.parseExpression(stream);
                stream.expect("TAG_END");
                return (0, deprecated_1.createDeprecatedNode)(expression, token.line, token.column, tag);
            };
        }
    };
};
exports.createDeprecatedTagHandler = createDeprecatedTagHandler;
