"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSpacelessTagHandler = void 0;
const spaceless_1 = require("../node/spaceless");
/**
 * Loops over each item of a sequence.
 *
 * <pre>
 * <ul>
 *  {% for user in users %}
 *    <li>{{ user.username|e }}</li>
 *  {% endfor %}
 * </ul>
 * </pre>
 */
const createSpacelessTagHandler = () => {
    const tag = 'spaceless';
    return {
        tag,
        initialize: (parser) => {
            return (token, stream) => {
                const { line, column } = token;
                console.warn(`The "spaceless" tag in "${stream.source.name}" at line ${line} is deprecated since Twig 2.7, use the "spaceless" filter instead.`);
                stream.expect("TAG_END");
                const body = parser.subparse(stream, tag, (token) => {
                    return token.test("NAME", 'endspaceless');
                });
                stream.next();
                stream.expect("TAG_END");
                return (0, spaceless_1.createSpacelessNode)(body, line, column, tag);
            };
        }
    };
};
exports.createSpacelessTagHandler = createSpacelessTagHandler;
